## neptune-sklearn 0.1.3

### Changes
- Moved neptune_sklearn package to src dir ([#5](https://github.com/neptune-ai/neptune-sklearn/pull/5))
- Poetry as a package builder ([#10](https://github.com/neptune-ai/neptune-sklearn/pull/10))

### Fixes
- Fixed imports from `neptune_sklearn.impl` -> now possible to import from `neptune_sklearn` ([#7](https://github.com/neptune-ai/neptune-sklearn/pull/7))

## neptune-sklearn 0.1.2

### Changes
- `get_estimator_params` works now with any scikit-learn estimator ([#3](https://github.com/neptune-ai/neptune-sklearn/pull/3))
